@@ -576,7 +576,7 @@ class BaseExperiment:
         self.fit_or_cv = fit_or_cv
         self.update_log_path()
         if self.data_module is None:
-            self.data_module = self.get_data_module(stratify=self.stratify)
+            self.data_module = self.get_data_module()
         if self.logger:
             self.logger.close()
             del self.logger
