@@ -11,6 +11,8 @@ from astrape.base.experiment_base import BaseExperiment
 from astrape.constants.astrape_constants import *
 from astrape.exceptions.exceptions import *
 import logging
+
+from benchay.codes.astrape_pkg.astrape.base.model_base import BaseNet
 log = logging.getLogger()
 log.setLevel(logging.INFO)
 
@@ -45,7 +47,6 @@ class CrossValidation(BaseExperiment):
     def __init__(
         self,
         project_name : str,
-        dims : int,
         X,
         y,
         n_classes : int,
@@ -166,7 +167,6 @@ class CrossValidation(BaseExperiment):
         self.parameters = parameters
         self.val_metric = val_metric
         self.cv = cv
-        self.dims = dims
         self.stratify = stratify
         if self.n_classes is None and self.stratify:
             log.info(f"Cannot perform label stratification in regression tasks. Setting stratify to False.")
@@ -297,6 +297,7 @@ class CrossValidation(BaseExperiment):
                     X_train, X_val, y_train, y_val = train_test_split(X, y, test_size=test_size, random_state=self.random_state, stratify=y)
                 else:
                     X_train, X_val, y_train, y_val = train_test_split(X, y, test_size=test_size, random_state=self.random_state)
+                
                 data_module = (X_train, X_val, y_train, y_val, X_test, y_test)
             elif X_val and y_val:
                 if self.stratify:
@@ -314,17 +315,7 @@ class CrossValidation(BaseExperiment):
                 data_module = (X_train, X_val, y_train, y_val, X_test, y_test)
 
         elif pl.LightningModule in inspect.getmro(self.model_type):
-            data_module = initialize_datamodule(
-                batch_size=batch_size, 
-                X=X, 
-                y=y,
-                X_val=X_val,
-                y_val=y_val,
-                X_test=X_test,
-                y_test=y_test,
-                test_size=test_size,
-                random_state=self.random_state
-            )
+            data_module = None
 
         return data_module
 
@@ -342,6 +333,7 @@ class CrossValidation(BaseExperiment):
         best_val_score = None
         best_hparams = None
         hparams_dict_list = self.get_hparams_dict_list()
+        
         for hparam_idx, hparams_dict in enumerate(hparams_dict_list):
             log.info(f"Stratified {self.cv}-Fold validation with {len(hparams_dict_list)} set of hyperparameters. Total {self.cv*len(hparams_dict_list)} runs will be conducted.")
             val_score_per_run = []
